
#include <avr/io.h>
#include <util/delay.h>
#include <stdio.h>

#define LATCH PB2
#define SCK PB5
#define INPUT PB4

#define YELLOW_LED PD2
#define GREEN_LED PD3

void setup();
uint8_t spiRead(uint8_t data);
uint8_t readShiftRegister();

int main() {
    setup();

    while (1)
    {
        uint8_t input = readShiftRegister();

        if (input& (1<<0)) PORTD |= 1 << GREEN_LED;
        else               PORTD &= ~(1 << GREEN_LED);


        if (input& (1<<1)) PORTD |= 1 << YELLOW_LED;
        else               PORTD &= ~(1 << YELLOW_LED);

        _delay_ms(500);
    }

    return 0;
}

void setup()
{
    DDRB &= ~(1 << INPUT);
    DDRB |= (1 << SCK) | (1 << LATCH);
    DDRD |= (1 << YELLOW_LED) | (1 << GREEN_LED);

    PORTB |= (1 << LATCH);

    SPCR = (1 << SPE) | (1 << MSTR) | (1 << SPR0); // Enable SPI, Master mode, Fosc/16
}

uint8_t spiRead( uint8_t data )
{
    SPDR = data;
    while (!(SPSR & (1<< SPIF)));
    return SPDR;
}

uint8_t readShiftRegister()
{
    PORTB &= ~(1 << LATCH);
    _delay_us(1);
    PORTB |= (1 << LATCH);

    uint8_t data = spiRead( 0xFF );

    return data;
}

